@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,25 +18,41 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdksddp.endpoint import endpoint_data
+
 class DescribeEventTypesRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Sddp', '2019-01-03', 'DescribeEventTypes','sddp')
+		self.set_method('POST')
 
-	def get_SourceIp(self):
-		return self.get_query_params().get('SourceIp')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-	def set_SourceIp(self,SourceIp):
-		self.add_query_param('SourceIp',SourceIp)
+	def get_ResourceId(self): # Integer
+		return self.get_query_params().get('ResourceId')
 
-	def get_ParentTypeId(self):
+	def set_ResourceId(self, ResourceId):  # Integer
+		self.add_query_param('ResourceId', ResourceId)
+	def get_FeatureType(self): # Integer
+		return self.get_query_params().get('FeatureType')
+
+	def set_FeatureType(self, FeatureType):  # Integer
+		self.add_query_param('FeatureType', FeatureType)
+	def get_ParentTypeId(self): # Long
 		return self.get_query_params().get('ParentTypeId')
 
-	def set_ParentTypeId(self,ParentTypeId):
-		self.add_query_param('ParentTypeId',ParentTypeId)
-
-	def get_Lang(self):
+	def set_ParentTypeId(self, ParentTypeId):  # Long
+		self.add_query_param('ParentTypeId', ParentTypeId)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_Status(self): # Integer
+		return self.get_query_params().get('Status')
+
+	def set_Status(self, Status):  # Integer
+		self.add_query_param('Status', Status)
